if [ ! -e /etc/wgetrc ]
then
    /usr/bin/mkdir -p /etc
    /usr/bin/cp /etc/defaults/etc/wgetrc /etc/wgetrc
fi

